@@ -1,10 +1,12 @@
 package WWW::Shorten::URLchen;
+
+use 5.006;
 use strict;
 use warnings;
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw( makeashorterlink makealongerlink );
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 use Carp;
 
@@ -74,10 +76,21 @@ If anything goes wrong, then either function will return C<undef>.
 
 makeashorterlink, makealongerlink
 
-=head1 SUPPORT, LICENCE, THANKS and SUCH
+=head1 SUPPORT, THANKS and SUCH
 
 See the main L<WWW::Shorten> docs.
 
+=head1 LICENSE
+
+This software is copyright (c) 2010 by Danijel Tasov
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 REPOSITORY
+
+L<https://github.com/datamuc/WWW-Shorten-URLchen>
+
 =head1 AUTHOR
 
 Danijel Tasov <data@cpan.org>
